Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(40)

Unified Diff: pkg/analyzer/lib/src/generated/utilities_general.dart

Issue 1139503002: Move 'dart:profiler' contents into 'dart:developer' and remove 'dart:profiler' (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/compiler/lib/src/dart2jslib.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/utilities_general.dart
diff --git a/pkg/analyzer/lib/src/generated/utilities_general.dart b/pkg/analyzer/lib/src/generated/utilities_general.dart
index e62a7815e633926fe40fca86a920a24f3b26ce59..6e15480d95e6807bc4e63d4941f4291f1e2ca494 100644
--- a/pkg/analyzer/lib/src/generated/utilities_general.dart
+++ b/pkg/analyzer/lib/src/generated/utilities_general.dart
@@ -7,7 +7,7 @@
library engine.utilities.general;
-import 'dart:profiler';
+import 'dart:developer';
/**
* Jenkins hash function, optimized for small integers.
@@ -34,7 +34,7 @@ class JenkinsSmiHash {
/**
* Helper class for gathering performance statistics. This class is modeled on
* the UserTag class in dart:profiler so that it can interoperate easily with
* it.
*/
abstract class PerformanceTag {
@@ -34,7 +34,7 @@ class JenkinsSmiHash {
/**
* Helper class for gathering performance statistics. This class is modeled on
- * the UserTag class in dart:profiler so that it can interoperate easily with
+ * the UserTag class in dart:developer so that it can interoperate easily with
* it.
*/
« no previous file with comments | « no previous file | pkg/compiler/lib/src/dart2jslib.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698